@@ -220,9 +220,6 @@ class ImportOrderChecker(object):
                 first_str = build_str(k)
                 second_str = build_str(pk)
 
-                print pn
-                print n
-
                 yield self.error(
                     node, "I100",
                     (
